@@ -8,7 +8,7 @@ import numpy as np
 from pathlib import Path
 from tensorflow_datasets.core.splits import Split
 from hcai_dataset_utils.statistics import Statistics
-
+from hcai_datasets.hcai_affectnet.hcai_affectnet_iterable import HcaiAffectnetIterable
 
 _DESCRIPTION = """
 Affectnet is a dataset that has been crawled from the internet and annotated with respect to affective classes as well as valence and arousal.
@@ -37,16 +37,26 @@ RELEASE_NOTES = {
 }
 
 
-class HcaiAffectnetConfig(tfds.core.BuilderConfig):
+class HcaiAffectnetConfig(tfds.core.BuilderConfig, HcaiAffectnetIterable):
     """BuilderConfig for HcaiAffectnetConfig."""
 
     def __init__(
-        self, *, include_auto=False, ignore_duplicate=True, ignore_lists=None, **kwargs
+        self,
+        *,
+        include_auto=False,
+        ignore_duplicate=True,
+        ignore_broken=True,
+        ignore_unsupported_format=True,
+        ignore_lists=None,
+        **kwargs
     ):
         """BuilderConfig for HcaiAffectnetConfig.
         Args:
+          ignore_duplicate: bool. Flag to determine whether the duplicated files in the dataset should be included. Only affects the training set.
+          ignore_broken: bool. Flag to determine whether the broken files in the dataset should be included.Affects all sets.
+          ignore_wrong_format:  bool. Flag to determine whether files that are not in tensorflow compatible encoding should be ignored. Affects all sets.
+          ignore_lists: list. Custom ignore lists for additional configurations.
           include_auto: bool. Flag to determine whether the automatically annotated files should be included in the dataset.
-          include_auto: bool. Flag to determine whether the duplicated files in the dataset should be included.
           **kwargs: keyword arguments forwarded to super.
         """
         super(HcaiAffectnetConfig, self).__init__(version=VERSION, **kwargs)
@@ -55,36 +65,53 @@ class HcaiAffectnetConfig(tfds.core.BuilderConfig):
 
         if ignore_duplicate:
             ignore_lists.append("affect_net_ignore_list_duplicates.json")
+
+        if ignore_broken:
+            ignore_lists.append("affect_net_broken_files_ignore_list.json")
+
+        if ignore_unsupported_format:
+            ignore_lists.append("affect_net_ignore_list_wrong_format.json")
+
         self.include_auto = include_auto
         self.ignore_lists = ignore_lists
 
 
-class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, Statistics):
+class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, HcaiAffectnetIterable, Statistics):
     """DatasetBuilder for hcai_affectnet dataset."""
 
     BUILDER_CONFIGS = [
-        HcaiAffectnetConfig(name="default", include_auto=False, ignore_duplicate=True),
-        HcaiAffectnetConfig(name="inc_auto", include_auto=True, ignore_duplicate=True),
+        HcaiAffectnetConfig(
+            name="default",
+            include_auto=False,
+            ignore_duplicate=True,
+            ignore_unsupported_format=True,
+        ),
+        HcaiAffectnetConfig(
+            name="inc_auto",
+            include_auto=True,
+            ignore_duplicate=True,
+            ignore_unsupported_format=True,
+        ),
+        HcaiAffectnetConfig(
+            name="emo_net",
+            include_auto=False,
+            ignore_duplicate=True,
+            ignore_unsupported_format=True,
+            ignore_lists=['affect_net_emo_net_ignore_list.json']
+        ),
     ]
 
-    IMAGE_FOLDER_COL = "image_folder"
-
-    def __init__(self, *, dataset_dir=None, **kwargs):
-        self.dataset_dir = dataset_dir
-        self.LABELS = [
-            "neutral",
-            "happy",
-            "sad",
-            "suprise",
-            "fear",
-            "disgust",
-            "anger",
-            "contempt",
-            "none",
-            "uncertain",
-            "non-face",
-        ]
-        super(HcaiAffectnet, self).__init__(**kwargs)
+    def __init__(self, *args, dataset_dir, **kwargs):
+        tfds.core.GeneratorBasedBuilder.__init__(self, *args, **kwargs)
+        if self.builder_config is None:
+            HcaiAffectnetIterable.__init__(self, *args, dataset_dir=dataset_dir, **kwargs)
+        else:
+            HcaiAffectnetIterable.__init__(
+                self, *args,
+                dataset_dir=dataset_dir,
+                include_auto=self.builder_config.include_auto,
+                ignore_lists=self.builder_config.ignore_lists,
+                **kwargs)
 
     def _info(self) -> tfds.core.DatasetInfo:
         """Returns the dataset metadata."""
@@ -95,6 +122,7 @@ class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, Statistics):
             features=tfds.features.FeaturesDict(
                 {
                     # These are the features of your dataset like images, labels ...
+                    "index": tf.string,
                     "image": tfds.features.Image(shape=(None, None, 3)),
                     "expression": tfds.features.ClassLabel(names=self.LABELS),
                     "arousal": tf.float32,
@@ -102,15 +130,15 @@ class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, Statistics):
                     "facial_landmarks": tfds.features.Tensor(
                         shape=(68, 2), dtype=tf.float32
                     ),
-                    "rel_file_path": tf.string
-                    #'face_bbox': tfds.features.BBox(),
+                    "rel_file_path": tf.string,
+                    #"face_bbox": tf.tuple(),
                 }
             ),
             supervised_keys=(
                 "image",
                 "expression",
-            ),  # Set to `None` to disable
-            homepage="https://dataset-homepage/",
+            ),
+            homepage="http://mohammadmahoor.com/affectnet/",
             citation=_CITATION,
         )
 
@@ -134,65 +162,8 @@ class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, Statistics):
 
     def _split_generators(self, dl_manager: tfds.download.DownloadManager):
         """Returns SplitGenerators."""
-        print("Loading Labels...")
 
-        train_csv_path = (
-            Path(self.dataset_dir) / "Manually_Annotated_file_lists" / "training.csv"
-        )
-        test_csv_path = (
-            Path(self.dataset_dir) / "Manually_Annotated_file_lists" / "validation.csv"
-        )
-
-        train_csv_path_auto = (
-            Path(self.dataset_dir)
-            / "Automatically_Annotated_file_lists"
-            / "automatically_annotated.csv"
-        )
-
-        train_df = pd.read_csv(train_csv_path, index_col=0)
-        test_df = pd.read_csv(test_csv_path, index_col=0)
-        train_df[self.IMAGE_FOLDER_COL] = ["Manually_Annotated_Images"] * len(train_df)
-        test_df[self.IMAGE_FOLDER_COL] = ["Manually_Annotated_Images"] * len(test_df)
-
-        # append automatic labels if not ignored:
-        if self.builder_config.include_auto:
-            train_df_auto = pd.read_csv(train_csv_path_auto, index_col=0)
-            train_df_auto[self.IMAGE_FOLDER_COL] = ["Automatically_Annotated_Images"]
-            train_df = pd.concat([train_df, train_df_auto])
-
-        len_train = len(train_df)
-        len_test = len(test_df)
-        print(
-            "...loaded {} images for train\n...loaded {} images for test".format(
-                len_train, len_test
-            )
-        )
-
-        # removing labels that are specified in the ignore-lists
-        print("Apply filtering...")
-
-        filter_list_path = Path(__file__).parent / "Ignore_Lists"
-        for filter_list in self._builder_config.ignore_lists:
-            with open(filter_list_path / filter_list) as json_file:
-                filter = json.load(json_file)
-                train_df.drop(filter, errors="ignore", inplace=True)
-                test_df.drop(filter, errors="ignore", inplace=True)
-        print(
-            "...dropped {} images from train\n... dropped {} images from test".format(
-                len_train - len(train_df), len_test - len(test_df)
-            )
-        )
-
-        # split train in validation an train
-        """print("Splitting validation set")
-        val_df = train_df.sample(frac=0.2, random_state=1337)
-        train_df = train_df.drop(val_df.index)
-        """
-        print(
-            "Final set sizes: \nTrain {}\nTest {}".format(len(train_df), len(test_df))
-        )
-
-        data = [(Split.TRAIN, train_df), (Split.TEST, test_df)]
+        data = [(Split.TRAIN, self.train_df), (Split.TEST, self.test_df)]
 
         self._populate_meta_data(data)
 
@@ -201,15 +172,6 @@ class HcaiAffectnet(tfds.core.GeneratorBasedBuilder, Statistics):
             for split_name, split_data in data
         }
 
-    def _generate_examples(self, label_df):
-        for index, row in label_df.iterrows():
-            yield index, {
-                "image": Path(self.dataset_dir) / row[self.IMAGE_FOLDER_COL] / index,
-                "expression": row["expression"],
-                "arousal": row["arousal"],
-                "valence": row["valence"],
-                "facial_landmarks": np.fromstring(
-                    row["facial_landmarks"], sep=";", dtype=np.float32
-                ).reshape((68, 2)),
-                "rel_file_path": row[self.IMAGE_FOLDER_COL] + "/" + index,
-            }
+    def _generate_examples(self, split_data):
+        for sample in self._yield_examples(split_data):
+            yield sample["index"], sample
\ No newline at end of file
